@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..1\n"; }
+BEGIN { $| = 1; print "1..4\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use News::Article::NoCeM;
 
@@ -14,20 +14,24 @@ $loaded = 1;
 print "ok 1\n";
 
 # the spam article
-my $article = new News::Article::NoCeM;
+my $article = new News::Article;
 
 # the nocem notice
 my $nocem = new News::Article::NoCeM;
 
+printf "%sok 2\n", $nocem ? "" : "not ";
+
 $article->set_headers('Newsgroups', 'the.spammed.group');
 $article->set_headers('From', 'Spam <spammer@spamhost.com>');
 $article->set_headers('Subject', 'This is a spam');
 $article->add_date();
 $article->add_message_id();
 
-$nocem->hide('spam', $article);
+my $hid = $nocem->hide('spam', $article);
+printf "%sok 3\n", $hid ? "" : "not ";
 
-$nocem->make_notice('spam', 'SpamKiller', 'the.nocem.group', 'nocem-issuer@email.address', 'This is a notice');
+my $notice = $nocem->make_notice('spam', 'SpamKiller', 'the.nocem.group', 'nocem-issuer@email.address', 'This is a notice');
+printf "%sok 4\n", $notice ? "" : "not ";
 
 # If you want to test it, please make sure your PGP key is ready.
 #$nocem->sign('YourKeyId', 'YourPassPhrase');
